@@ -1021,13 +1021,20 @@ bool LadspaLoader::load(pluginarray& ml) {
     return true;
 }
 
-void LadspaLoader::set_plugins(pluginarray& new_plugins) {
+void LadspaLoader::change_plugins(pluginarray& new_plugins) {
     for (pluginarray::iterator i = plugins.begin(); i != plugins.end(); ++i) {
 	delete *i;
     }
     plugins = new_plugins;
 }
 
+void LadspaLoader::set_plugins(pluginarray& new_plugins) {
+    //for (pluginarray::iterator i = plugins.begin(); i != plugins.end(); ++i) {
+	//delete *i;
+    //}
+    plugins = new_plugins;
+}
+
 LadspaLoader::pluginarray::iterator LadspaLoader::find(plugdesc *desc) {
     for (pluginarray::iterator i = begin(); i != end(); ++i) {
 	if (desc->quirks & is_lv2) {
