@@ -265,6 +265,7 @@ void GxUiRadioMenu::setup(const Glib::ustring& prefix, const Glib::ustring& post
 		sigc::mem_fun(*this, &GxUiRadioMenu::on_changed));
 	    action = act;
 	}
+    //fprintf(stderr, "%s  \n", p->value_id); 
     }
     s.append(postfix);
     uimanager->add_ui_from_string(s);
@@ -504,6 +505,7 @@ void MainWindow::load_widget_pointers() {
     bld->find_widget("tuner_mode", tuner_mode);
     bld->find_widget("tuner_reference_pitch", tuner_reference_pitch);
     bld->find_widget("tuner_tuning", tuner_tuning);
+    bld->find_widget("tuner_temperament", tuner_temperament);
     bld->find_widget("racktuner", racktuner);
     bld->find_widget("ampdetail_compress:effect_reset", ampdetail_compress);
     bld->find_widget("ampdetail_expand:effect_reset", ampdetail_expand);
@@ -1704,7 +1706,10 @@ void MainWindow::on_plugin_changed(gx_engine::Plugin *pl, gx_engine::PluginChang
 	    }
 	} else {
 	    assert(c == gx_engine::PluginChange::update || c == gx_engine::PluginChange::update_category);
+        //if (!pui->plugin->get_box_visible())
+        bool state =  pui->plugin->get_on_off();
 	    pui->update_rackbox();
+        pui->plugin->set_on_off(state);
 	    if (c == gx_engine::PluginChange::update_category) {
 		pui->unset_ui_merge_id(uimanager);
 		pui->group = add_plugin_category(pui->get_category());
@@ -1818,6 +1823,7 @@ Glib::ustring MainWindow::add_plugin_menu_entry(PluginUI *pui) {
     Glib::ustring actionname = Glib::ustring::compose("Plugin_%1", pui->get_id());
     const char *tp = (pui->get_type() == PLUGIN_TYPE_MONO ? "Mono" : "Stereo");
     pui->set_ui_merge_id(uimanager->add_ui_from_string(Glib::ustring::compose(ui_template, tp, groupname, actionname)));
+    //fprintf(stderr, "%s : %s : %s \n", tp, group, pui->get_name());    
     return actionname;
 }
 
@@ -2063,13 +2069,19 @@ void MainWindow::set_tuning(Gxw::RackTuner& tuner) {
     if (mode > 0) {
 	tuner.set_display_flat(tuning_tab[mode-1].flat);
 	for (int i = 0; i < 6; ++i) {
-	    tuner.push_note(tuning_tab[mode-1].notes[i]);
+	    tuner.push_note(tuning_tab[mode-1].notes[i], 69, 12);
 	}
     } else {
 	tuner.set_display_flat(false);
     }
 }
 
+void MainWindow::setup_tuner_temperament(Gxw::RackTuner& tuner) {
+    tuner.set_temperament(tuner_temperament->get_value());
+    set_tuning(tuner);
+
+}
+
 void MainWindow::setup_tuner(Gxw::RackTuner& tuner) {
     tuner.signal_frequency_poll().connect(
 	sigc::compose(
@@ -2085,6 +2097,9 @@ void MainWindow::setup_tuner(Gxw::RackTuner& tuner) {
 	    sigc::mem_fun(*tuner_reference_pitch, &Gxw::Wheel::get_value)));
     tuner_tuning->signal_value_changed().connect(
 	sigc::bind(sigc::mem_fun(*this, &MainWindow::set_tuning), sigc::ref(tuner)));
+    tuner_temperament->signal_value_changed().connect(
+        sigc::bind(sigc::mem_fun(*this, &MainWindow::setup_tuner_temperament), sigc::ref(tuner)));
+	
 }
 
 bool MainWindow::on_toggle_mute(GdkEventButton* ev) {
@@ -2822,6 +2837,7 @@ MainWindow::MainWindow(gx_engine::GxMachineBase& machine_, gx_system::CmdlineOpt
     } else {
       gtk_rc_parse(
           (options.get_style_filepath("clear.rc")).c_str());
+      make_icons();
     }
 
     // call some action functions to sync state
